function dibujar_secciones(s,varargin)

% Este programa dibuja las diferentes secciones de un barco
% dados unos ciertos puntos de control por seccin
% dibujar_secciones(s,varargin)
% Variables de entrada:
% s estructura que contiene la informacin de las secciones.
%   Sus campos son los siguientes:
%   s.x  posicin espacial x de la seccin
%   s.numero  nmero de puntos de control en la seccin considerada
%   s.puntos coordenadas (y,z) de los puntos de control
%   s.tipo tipo de poligonal entre un punto y el siguiente. Puede
%          ser paralela al eje y, paralela al eje z, u oblicua
%   s.poligonal informacin necesaria para construir la poligonal
%   s.limites indica de dnde a dnde se extiende cada lnea de la
%             poligonal
% k argumento opcional que indica el nmero de seccin que se quiere
%   dibujar
% rango  vector [k1,k2] que indica desde que seccin a qu seccin se
%   quiere dibujar
% all dibuja todas las secciones secuencialmente con una pausa entre
%     ellas
% grupo,m,p  las dibuja agrupadas en grupos de m x p secciones
% superpuestas,[k1,k2]

% creamos una ventana nueva donde dibujar
h=figure('Tag','secciones','Name',[blanks(6),'Secciones'],'Position',[100 100 1000 600]);
axis off

% Centramos y escalamos
set( h,'Units', 'pixels' );
screenSize = get(0, 'ScreenSize');

position = get( h,'Position');
position(1) = (screenSize(3)-position(3))/2;
position(2) = (screenSize(4)-position(4))/2;
set( h,'Position', position );


% nmero de secciones
n=length(s);

% calculamos los valores mnimos y mximos de las variables y,z

ym=min(s(1).puntos(:,1));
yM=max(s(1).puntos(:,1));
zm=min(s(1).puntos(:,2));
zM=max(s(1).puntos(:,2));

for i=2:n

    aux_ym=min(s(i).puntos(:,1));
    if aux_ym < ym
        ym=aux_ym;
    end
    aux_yM=max(s(i).puntos(:,1));
    if aux_yM>yM
        yM=aux_yM;
    end
    aux_zm=min(s(i).puntos(:,2));
    if aux_zm<zm
        zm=aux_zm;
    end
    aux_zM=max(s(i).puntos(:,2));
    if aux_zM>zM
        zM=aux_zM;
    end

end

dy=(yM-ym)/10;
dz=(zM-zm)/10;

if nargin==2

    in=varargin{1};

    if isnumeric(in)     % o una seccin o un rango de secciones

        if length(in)==1   % es una seccin

            aux=s(in).puntos;
            aux=[aux;aux(1,1:2)];
            plot(aux(:,1),aux(:,2));
            ym=min(aux(:,1));
            yM=max(aux(:,1));
            zm=min(aux(:,2));
            zM=max(aux(:,2));
            if yM~=ym
                dy=(yM-ym)/10;
            end
            if zM~=zm
                dz=(zM-zm)/10;
            end
            axis([ym-dy yM+dy zm-dz zM+dz]);
            title(['Seccin ',num2str(in),'   x=',num2str(s(in).x)])
            xlabel('Eje y')
            ylabel('Eje z')

        elseif length(in)==2    % es un rango de secciones

            for k=in(1):in(2)

                aux=s(k).puntos;
                aux=[aux;aux(1,1:2)];
                plot(aux(:,1),aux(:,2));
                ym=min(aux(:,1));
                yM=max(aux(:,1));
                zm=min(aux(:,2));
                zM=max(aux(:,2));
                if yM~=ym
                    dy=(yM-ym)/10;
                end
                if zM~=zm
                    dz=(zM-zm)/10;
                end
                axis([ym-dy yM+dy zm-dz zM+dz]);
                title(['Seccin ',num2str(k),'   x=',num2str(s(k).x)])
                xlabel('Eje y')
                ylabel('Eje z')
                pause

            end
        end

    elseif ischar(in)   % todas las secciones


        for k=1:n

            aux=s(k).puntos;
            aux=[aux;aux(1,1:2)];
            plot(aux(:,1),aux(:,2));
            ym=min(aux(:,1));
            yM=max(aux(:,1));
            zm=min(aux(:,2));
            zM=max(aux(:,2));
            if yM~=ym
                dy=(yM-ym)/10;
            end
            if zM~=zm
                dz=(zM-zm)/10;
            end
            axis([ym-dy yM+dy zm-dz zM+dz]);
            title(['Seccin ',num2str(k),'   x=',num2str(s(k).x)])
            xlabel('Eje y')
            ylabel('Eje z')
            pause

        end


    end

elseif nargin==3

    in=varargin{2};

    for k=in(1):in(2)

        aux=s(k).puntos;
        aux=[aux;aux(1,1:2)];
        plot(aux(:,1),aux(:,2));
        hold on
        ym=min([ym,min(aux(:,1))]);
        yM=max([yM,max(aux(:,1))]);
        zm=min([zm,min(aux(:,2))]);
        zM=max([zM,max(aux(:,2))]);
        if yM~=ym
            dy=(yM-ym)/10;
        end
        if zM~=zm
            dz=(zM-zm)/10;
        end
        axis([ym-dy yM+dy zm-dz zM+dz]);
        title(['Seccin ',num2str(k),'   x=',num2str(s(k).x)])
        xlabel('Eje y')
        ylabel('Eje z')
        pause

    end

elseif nargin==4

    m=varargin{2};
    p=varargin{3};
    mp=m*p;

    co=floor(n/mp);           % nmero de plots a hacer menos 1
    re=rem(n,mp);             % nmero de secciones en el ltimo plot


    for np=1:co


        for k=1:mp

            indice=mp*(np-1)+k;
            aux=s(indice).puntos;
            aux=[aux;aux(1,1:2)];
            subplot(m,p,k);
            plot(aux(:,1),aux(:,2));
            ym=min(aux(:,1));
            yM=max(aux(:,1));
            zm=min(aux(:,2));
            zM=max(aux(:,2));
            if yM~=ym
                dy=(yM-ym)/10;
            end
            if zM~=zm
                dz=(zM-zm)/10;
            end
            axis([ym-dy yM+dy zm-dz zM+dz]);
            title(['Seccin ',num2str(indice),'   x=',num2str(s(indice).x)])
            xlabel('Eje y')
            ylabel('Eje z')

        end

        pause


    end

    
    hold off
    close(h)
    % creamos una ventana nueva donde dibujar
    h=figure('Tag','secciones','Name',[blanks(6),'Secciones'],'Position',[100 100 1000 600]);
    axis off
    
    
    for k=1:re


        indice=mp*co+k;
        aux=s(indice).puntos;
        aux=[aux;aux(1,1:2)];
        subplot(m,p,k);
        plot(aux(:,1),aux(:,2));
        ym=min(aux(:,1));
        yM=max(aux(:,1));
        zm=min(aux(:,2));
        zM=max(aux(:,2));
        if yM~=ym
            dy=(yM-ym)/10;
        end
        if zM~=zm
            dz=(zM-zm)/10;
        end
        axis([ym-dy yM+dy zm-dz zM+dz]);
        title(['Seccin ',num2str(indice),'   x=',num2str(s(indice).x)])
        xlabel('Eje y')
        ylabel('Eje z')

    end


end