function  dibujo_barco_grada(i0,xi0,alfa,semimangas,densidad,Xg,Zg)

% Este programa dibuja de manera esquemtica el barco con el que se trabaja
% a diferentes alturas de agua en la grada durante la botadura. Se indica
% la posicin del centro de empuje
%
% dibujo_barco_grada(i0,xi0,alfa,semimangas,densidad,Xg,Zg,M);
%
% Variables de entrada:
% i0 nmero de seccin a la que llega el nivel del agua
% xi0 coordenada x correspondiente o bien a la ltima seccin mojada o bien
%     a una distancia superior a ella que indica el nivel del agua
% alfa ngulo de inclinacin de la grada
% semimangas matriz que contiene las dimensiones x,y,z del barco
% densidad del lquido donde se sumerge el barco
%                densidad agua dulce=1
%                densidad agua salada=1.025
% Xg posicin longitudinal del centro de pesos
% Zg posicin vertical del centro de pesos


screenSize = get(0, 'ScreenSize');
p1=screenSize(1)+50;
p2=screenSize(2)+50;
p3=screenSize(3)-150;
p4=screenSize(4)-150;


[n,m]=size(semimangas);
x=semimangas(1,2:end);
z=semimangas(2:end,1);
y=semimangas(2:end,2:end);
[X,Z]=meshgrid(x,z);


cond1=(y~=0);
cond2=~(-tan(alfa)*(X-xi0)<Z);
M=ones(size(y));


yc=1*(cond1 & (~cond2)).*M+0.7*(cond1 & cond2).*M+ 0.4*((~cond1) & cond2).*M+0*((~cond1) & (~cond2)).*M;


if isempty(find(yc==0.7))
    
    % dibujamos el barco sin mojar
    figure(1); set(1,'Name','Posicin del Centro de Empuje','Position',[p1 p2 p3 p4]);
    RGB1=[1,1,1; 0,1,1; 0,0,0];
    colormap(RGB1);
    pcolor(X,Z,yc);
    axis('image');
else
    
    % dibujamos el barco mojado
    figure(1); set(1,'Name','Posicin del Centro de Empuje','Position',[p1 p2 p3 p4]);
    RGB1=[1,1,1; 0,1,1; 0,0,1;0,0,0];
    colormap(RGB1);
    pcolor(X,Z,yc);
    axis('image');
    
    
end


% dibujamos el lmite de la parte mojada

hold on
xr=0:1/100:xi0;
yr=-tan(alfa)*(xr-xi0);


plot(xr,yr,'y','LineWidth',3)

% dibujamos el centro de pesos

plot(Xg,Zg,'o','MarkerSize',7,'MarkerFaceColor','g');

% dibujamos el centro de empuje

if i0>m-1
    [empuje,centro_empuje]=hidrostatica_alfa(m-1,xi0,alfa,semimangas,densidad);
else
    [empuje,centro_empuje]=hidrostatica_alfa(i0,xi0,alfa,semimangas,densidad);
end

plot(centro_empuje(1),centro_empuje(3),'ro','MarkerSize',5,'MarkerFaceColor','r')

hold off


