function [empuje,centro_empuje]=hidrostatica_alfa(i0,xi0,alfa,semimangas,densidad)

% Esta funcin calcula el empuje (volumen por densidad) y el centro de
% empuje (centro de gravedad de la parte sumergida) de un barco que est
% siendo botado
% [empuje,centro_empuje]=hidrostatica_alfa(i0,xi0,alfa,semimangas,densidad)
% Variables de entrada:
% i0 ndice de la coordenada x0 de la ltima seccin mojada
% xi0 coordenada x correspondiente o bien a la ltima seccin mojada o bien
%     a una distancia superior a ella que indica el nivel del agua
% alfa ngulo de inclinacin de la grada
% semimangas matriz que contiene los datos de cada linea de agua
% densidad del lquido donde se sumerge el barco
%                densidad agua dulce=1
%                densidad agua salada=1.025
% Variables de salida:
% empuje que se calcula como el volumen de la parte sumergida multiplicado
%        por la densidad del agua
% centro_empuje  centro de gravedad de la parte sumergida del barco


% Tamao de la matriz de datos que contiene las lneas de agua
[n,m]=size(semimangas);

% secciones
x=semimangas(1,2:m);    % tamao 1 x m-1

% alturas
z=semimangas(2:n,1);    % tamao n-1 x 1

% semimangas
y=semimangas(2:n,2:m);  % tamao n-1 x m-1


% Realiza el clculo de los parmetros hidrostticos de cada uno de los
% calados

for k=1:n-1
    
    % Determinamos la longitud de la semimanga mojada dependiendo de la altura z
    y_linea=[];
    indicex=1;
    while -tan(alfa)*(x(indicex)-xi0)>=z(k) & indicex<i0
        y_linea=[y_linea,y(k,indicex)];
        indicex=indicex+1;
    end
    
    % Calculamos el rea sumergida a altura z
    if isempty(y)
        Aw(k)=0;
    else
        Aw(k)=2*trapecios(x(1:length(y_linea)),y_linea);
    end
    
end

% Calculamos el volumen mojado y el centro de gravedad de dicho volumen

V=trapecios(z(1:n-1)',Aw(1:n-1));   % Volumen de desplazamiento 
MB=trapecios(z(1:n-1)',z(1:n-1)'.*Aw(1:n-1));  % Momento de desplazamiento respecto de z
cgz=MB/V;                       % Coordenada z del centro de carena


% Realiza el clculo de los parmetros hidrostticos de cada uno de las secciones

for i=1:i0
    
    % Determinamos la longitud de la semimanga mojada dependiendo de la
    % seccin x
    y_linea=[];
    indicez=n-1;
    while z(indicez)<=-tan(alfa)*(x(i)-xi0)
        y_linea=[y_linea,y(indicez,i)];
        indicez=indicez-1;
    end
    
    % Calculamos el rea sumergida para cada seccin
    if isempty(y_linea)
        As(i)=0;
    else
        As(i)=2*trapecios(z(indicez+1:indicez+length(y_linea))',y_linea);
    end
end

MBx=trapecios(x(1:i0),x(1:i0).*As(1:i0));                     % Momento respecto de la seccin
Vx=trapecios(x(1:i0),As(1:i0));            % Volumen de desplazamiento
cgx=MBx/Vx;                                % Coordenada x del centro de empuje


% Expresamos el empuje y el centro de empuje
empuje=densidad*V;
centro_empuje=[cgx,0,cgz];
