function [Tpr, Tpp, beta]=obtencion_calados(fichero,v,Xg)

% Este programa calcula los calados de proa y de popa
% basndose en los clculos hidrostticos hechos en adrizado
%
% [Tpr, Tpp, beta]=obtencion_calados(fichero,v,Xg)
% Variables de entrada:
% fichero archivo excel que contiene los valores hidrostticos necesarios
%         a diferentes calados
% v  vector que contiene los valores hidrostticos necesarios para
%    el calado de flotacin
% Xg coordenada x del centro de gravedad del barco real
% Variables de salida:
% Tpr calado en proa
% Tpp calado en popa
% beta ngulo de inclinacin del barco en flotacin


% Clculo del trimado

D=v(6);               % desplazamiento en calado de flotacin
MTC=v(11);            % momento para el trimado de un centmetro
XB=v(8);              % coordenada x del centro del centro de carena
Xf=v(4);              % coordenada x del centro de flotacin

t=D*abs(Xg-XB)/MTC/100;

% Clculo del ngulo beta de giro del barco hasta la posicin de equilibrio

L=v(14);             % eslora en calado de flotacin
beta=atan(t/L);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calado de proa y de popa
%%%%%%%%%%%%%%%%%%%%%%%%%%%%



% Bucles para calcular las distancias df y da


% Lee las variables hidrostticas calculadas

numeric=xlsread(fichero);
[n,m]=size(numeric);

calados=numeric(:,1);

ind=find(calados<v(1));
ind=ind(1);

if Xg>XB

    % Bucle para calcular la distancia df

    i=ind-1;
    calado=v(1);
    calado_recta=calado+1;

    while calado_recta>calado &  i>=1
        xmax=numeric(i,13);
        calado_recta=v(1)+tan(beta)*(xmax-Xf);
        calado=calados(i);
        i=i-1;
    end

    xdf=(numeric(i+2,13)+xmax)/2;


    df=xdf-Xf;


    % Bucle para calcular la distancia da

    i=ind+2;
    calado=v(1);
    calado_recta=calado-1;

    while calado_recta<calado &  i<=length(calados)
        xmin=numeric(i,12);
        calado_recta=v(1)+tan(beta)*(xmin-Xf);
        calado=calados(i);
        i=i+1;
    end

    xda=(numeric(i-2,12)+xmin)/2;


    da=Xf-xda;

    % Calado de proa

    f=t/(da/df+1);
    Tpr=v(1)+f;

    % Calado de popa
    a=t-f;
    Tpp=v(1)-a;


elseif Xg<XB

    % Bucle para calcular la distancia da

    i=ind-1;
    calado=v(1);
    calado_recta=calado+1;

    while calado_recta>calado &  i>=1
        xmin=numeric(i,12);
        calado_recta=v(1)+tan(beta)*(xmin-Xf);
        calado=calados(i);
        i=i-1;
    end

    xda=(numeric(i+2,12)+xmin)/2;


    da=Xf-xda;


    % Bucle para calcular la distancia df

    i=ind+2;
    calado=v(1);
    calado_recta=calado-1;

    while calado_recta<calado &  i<=length(calados)
        xmax=numeric(i,13);
        calado_recta=v(1)+tan(beta)*(xmax-Xf);
        calado=calados(i);
        i=i+1;
    end

    xdf=(numeric(i-2,13)+xmax)/2;


    df=xdf-Xf;

    % Calado de proa

    f=t/(da/df+1);
    Tpr=v(1)-f;

    % Calado de popa
    a=t-f;
    Tpp=v(1)+a;

else

    Tpr=v(1);

    Tpp=Tpr;
end



