function [semimanga]=obtener_LineasDeAgua(s,nl,fichero,varargin)

% Esta funcin calcula para cada z entre la altura mnima y la altura 
% mxima del barco (o el calado mximo introducido) 
% tantas lneas de agua como sean necesarias
% [z,semimanga]=obtener_LineasDeAgua(s,nl,fichero,varargin)
% Variables de entrada
% s estructura que contiene la informacin de las secciones.
%   Sus campos son los siguientes:
%   s.x  posicin espacial x de la seccin
%   s.numero  nmero de puntos de control en la seccin considerada
%   s.puntos coordenadas (y,z) de los puntos de control
%   s.tipo tipo de poligonal entre un punto y el siguiente. Puede
%          ser paralela al eje y, paralela al eje z, u oblicua
%   s.poligonal informacin necesaria para construir la poligonal
%   s.limites indica de dnde a dnde se extiende cada lnea de la
%             poligonal
% nl nmero de lneas de agua que se quieren calcular
% fichero nombre del fichero donde se quieren guardar las lineas de agua
% calado valor mximo de la altura para el que se quieren realizar 
%        los clculos
% Variables de salida:
% semimanga contiene lo siguiente:
%           En la posicin (1,1) un cero que no indica nada
%           En la primera fila, a partir de la segunda celda, la coordenada
%               x de las cuadernas
%           En la primera columna, a partir de la segunda celda, la
%           coordenada z que indica la altura
%           En las celdas (2:end, 2:end)  las semimangas para los valores
%               de x y de z correspondientes



% nmero de secciones
n=length(s);

% calculamos el valor mnimo y mximo de la variable z

zm=min(s(1).puntos(:,2));
zM=max(s(1).puntos(:,2));

for i=2:n

    aux_zm=min(s(i).puntos(:,2));
    if aux_zm<zm
        zm=aux_zm;
    end
    aux_zM=max(s(i).puntos(:,2));
    if aux_zM>zM
        zM=aux_zM;
    end

end


% comprueba si quiere todas las alturas de calado, o 
% desde un calado mximo dado

if nargin==4
    aux=zM;
    zM=varargin{1};
    if zM>aux
         zM=aux;
         uiwait(msgbox(['Se va a trabajar con el calado mximo zM=',num2str(aux)], 'Mensaje de error',...
        'error','modal'));
         return;
    end
end



% calculamos la altura de las diferentes lneas de agua

z=fliplr(linspace(zm,zM,nl));

% calculamos la semimanga para cada z y para cada seccin
% y la guardamos en la matriz semimanga
% La primera fila de semimanga contiene la lnea de agua
% a altura mxima del barco

for i=1:nl

    % cortamos la recta z=altura de la lnea de agua
    % con cada una de las secciones
    
    for j=1:n
        
        % miramos si la recta corta a cada una de los
        % lados de la poligonal que forma la seccin
        
        semimanga(i,j)=0;
        
        for k=1:s(j).numero
        
            if strcmp(deblank(s(j).tipo(k,:)),'Paralela al Eje z')
                if (z(i)>=s(j).limites(k,1)) & (z(i)<=s(j).limites(k,2))
                    if s(j).poligonal(k,1)>semimanga(i,j)
                        semimanga(i,j)=s(j).poligonal(k,1);
                        break;
                    end
                end               
            elseif strcmp(deblank(s(j).tipo(k,:)),'Paralela al Eje y')
                if abs(z(i)-s(j).poligonal(k,1))<10^(-15)
                    if s(j).limites(k,2)>semimanga(i,j)
                        semimanga(i,j)=s(j).limites(k,2);
                        break;
                    end
                end
            elseif strcmp(deblank(s(j).tipo(k,:)),'Oblicua')
                aux=s(j).poligonal(k,1)*z(i)+s(j).poligonal(k,2);
                if s(j).limites(k,1)<=aux & aux<=s(j).limites(k,2)
                    if aux>semimanga(i,j)
                        semimanga(i,j)=aux;
                        break;
                    end
                end
            end
    
        end
    
    
    

    end
    
end

% generamos las coordenadas x de las secciones de popa a proa

for i=1:length(s)
    x(i)=s(i).x;
end


% % ponemos el vector de cuadernas en la primera fila de la
% % matriz de semimangas

semimanga=fliplr(semimanga);
semimanga=[x;semimanga];

% ponemos el vector de alturas z en la primera columna, completando
% la primera entrada con el valor de 0

z=[0;z'];
semimanga=[z,semimanga];

% si el fichero de salida ya existe lo borramos antes 
d=dir('./Lneas de Agua/');

nd=length(d);

for i=1:nd
    a=strmatch(d(i).name,fichero);
    if a==1
        delete(['./Lneas de Agua/',fichero]);
        break;
    end
end



% guardamos en un fichero excel .xls la matriz semimanga

success = xlswrite(['./Lneas de Agua/',fichero],semimanga);

